=======
Credits
=======

Core team
---------

* Antonis Sgouros <antonis@askanna.io>
* Wai Yi Anthony Leung <anthony@askanna.io>

Contributors
------------

Your name here? Open a ticket and start adding features to AskAnna!
